@@ -1,17 +1,19 @@
 import type { Metadata } from "next";
-import { Geist_Mono } from "next/font/google";
+import { JetBrains_Mono } from "next/font/google";
 import "./globals.css";
 import { Providers } from "@/lib/providers";
 import { AuthGuard } from "@/components/AuthGuard";
+import { getAppName, getVersion } from "@/lib/version";
 
-const geistMono = Geist_Mono({
+const jetbrainsMono = JetBrains_Mono({
   variable: "--font-mono",
   subsets: ["latin"],
+  weight: ["100", "200", "300", "400", "500", "600", "700", "800"],
 });
 
 export const metadata: Metadata = {
-  title: "mem8 | Terminal Memory Interface",
-  description: "Terminal-style memory management for the orchestr8 ecosystem",
+  title: `${getAppName()} | Terminal IDE for Thoughts & Knowledge`,
+  description: "A terminal-style IDE for managing thoughts, research, and plans with YAML frontmatter",
   icons: {
     icon: '/favicon.ico',
     apple: '/apple-touch-icon.png',
@@ -26,7 +28,7 @@ export default function RootLayout({
   return (
     <html lang="en" className="dark">
       <body
-        className={`${geistMono.variable} bg-grid bg-scanlines`}
+        className={`${jetbrainsMono.variable} bg-grid bg-scanlines`}
       >
         <Providers>
           <AuthGuard>
