@@ -1,20 +1,28 @@
 "use client";
 
 import { useEffect, useState } from 'react';
+import { useRouter } from 'next/navigation';
 import { Button } from '@/components/ui/button';
 import { Badge } from '@/components/ui/badge';
 import { UserDropdown } from '@/components/UserDropdown';
-import { Search, Brain, Users, Zap, Database, Terminal, Plus, RefreshCw, Download } from 'lucide-react';
+import { Search, Brain, Users, Zap, Database, Terminal, Plus, RefreshCw, Download, FileText, Code } from 'lucide-react';
 import Image from 'next/image';
 import { useHealth, useThoughts, useFilesystemThoughts, useTeams, useSystemStats, useSearchThoughts, useSyncTeam, useCreateThought } from '@/hooks/useApi';
 import { useWebSocket } from '@/hooks/useWebSocket';
 import { useAuth } from '@/hooks/useAuth';
 import { cn } from '@/lib/utils';
+import { detectContentType, parseYamlMetadata } from '@/lib/content-types';
+import { MetadataPanel } from '@/components/MetadataPanel';
+import { getAppTitle } from '@/lib/version';
 
 export default function Home() {
   const [searchQuery, setSearchQuery] = useState('');
   const [selectedTeamId, setSelectedTeamId] = useState<string | undefined>();
-  const [searchType, setSearchType] = useState<'fulltext' | 'semantic'>('fulltext');
+  const [contentTypeFilter, setContentTypeFilter] = useState<'all' | 'research' | 'plan'>('all');
+  const [searchType] = useState<'fulltext' | 'semantic'>('fulltext');
+  
+  // Router hook
+  const router = useRouter();
   
   // Auth hook
   const { user, isAuthenticated, isLoading: authLoading, logout, getGitHubAuthUrl } = useAuth();
@@ -27,6 +35,10 @@ export default function Home() {
     limit: 10
   });
   
+  // Type helper for filesystem thoughts API response
+  // eslint-disable-next-line @typescript-eslint/no-explicit-any
+  const fsThoughts = filesystemThoughts as any;
+  
   const { data: thoughts, isLoading: thoughtsLoading, refetch: refetchThoughts } = useThoughts({
     team_id: selectedTeamId,
     limit: 10
@@ -50,7 +62,7 @@ export default function Home() {
   });
   
   // TODO: activeUsers will be implemented when WebSocket user tracking is added
-  const activeUsers: any[] = [];
+  const activeUsers: unknown[] = [];
 
   // Warn when backend/system values are missing so users can configure them
   useEffect(() => {
@@ -61,7 +73,6 @@ export default function Home() {
       if (systemStats.syncStatus == null) missing.push('syncStatus');
       if (systemStats.memoryUsage == null) missing.push('memoryUsage');
       if (missing.length) {
-        // eslint-disable-next-line no-console
         console.warn(
           `System stats missing: ${missing.join(', ')}. Ensure backend /api/v1/system/stats provides these fields.`
         );
@@ -73,7 +84,6 @@ export default function Home() {
     if (teams && teams.length) {
       const missingMemberCount = teams.filter(t => t?.settings?.memberCount == null).length;
       if (missingMemberCount > 0) {
-        // eslint-disable-next-line no-console
         console.warn(
           `${missingMemberCount} team(s) missing settings.memberCount. Set this in team configuration to show accurate member counts.`
         );
@@ -156,33 +166,58 @@ export default function Home() {
   
   // Transform thoughts data for display - prioritize filesystem thoughts
   const recentThoughts = (() => {
+    let thoughts = [];
+    
     if (searchQuery.length > 2) {
-      return searchResults?.thoughts || [];
+      thoughts = searchResults?.thoughts || [];
+    } else if (fsThoughts?.thoughts) {
+      // Use filesystem thoughts if available
+      // eslint-disable-next-line @typescript-eslint/no-explicit-any
+      thoughts = fsThoughts.thoughts.slice(0, 50).map((thought: any) => {
+        const contentType = detectContentType(thought.tags || []);
+        const metadata = parseYamlMetadata(thought.content);
+        
+        return {
+          id: thought.id,
+          title: thought.title,
+          excerpt: thought.content.substring(0, 150) + '...',
+          path: thought.path,
+          team: thought.repository || 'Local',
+          lastModified: new Date(thought.updated_at).toLocaleString(),
+          tags: thought.tags || [],
+          contentType,
+          metadata,
+          fullContent: thought.content
+        };
+      });
+    } else {
+      // Fallback to database thoughts
+      thoughts = thoughts?.slice(0, 50).map(thought => {
+        const tags = Array.isArray(thought.thought_metadata?.tags) ? thought.thought_metadata.tags : [];
+        const contentType = detectContentType(tags);
+        const metadata = parseYamlMetadata(thought.content);
+        
+        return {
+          id: thought.id,
+          title: thought.title,
+          excerpt: thought.content.substring(0, 150) + '...',
+          path: thought.path,
+          team: currentTeam?.name || 'Unknown Team',
+          lastModified: new Date(thought.updated_at).toLocaleString(),
+          tags,
+          contentType,
+          metadata,
+          fullContent: thought.content
+        };
+      }) || [];
     }
     
-    // Use filesystem thoughts if available
-    if (filesystemThoughts?.thoughts) {
-      return filesystemThoughts.thoughts.slice(0, 10).map((thought: any) => ({
-        id: thought.id,
-        title: thought.title,
-        excerpt: thought.content.substring(0, 150) + '...',
-        path: thought.path,
-        team: thought.repository || 'Local',
-        lastModified: new Date(thought.updated_at).toLocaleString(),
-        tags: thought.tags || []
-      }));
+    // Apply content type filter
+    if (contentTypeFilter !== 'all') {
+      thoughts = thoughts.filter(thought => thought.contentType === contentTypeFilter);
     }
     
-    // Fallback to database thoughts
-    return thoughts?.thoughts?.slice(0, 10).map(thought => ({
-      id: thought.id,
-      title: thought.title,
-      excerpt: thought.content.substring(0, 150) + '...',
-      path: thought.path,
-      team: currentTeam?.name || 'Unknown Team',
-      lastModified: new Date(thought.updated_at).toLocaleString(),
-      tags: thought.thought_metadata.tags || []
-    })) || [];
+    return thoughts.slice(0, 10);
   })();
   
   // Transform teams data for team status display
@@ -208,7 +243,7 @@ export default function Home() {
       <div className="min-h-screen bg-black text-green-400 font-mono flex items-center justify-center">
         <div className="max-w-md w-full text-center space-y-4">
           <div className="text-2xl font-bold">
-            &gt; mem8 TERMINAL
+            &gt; AgenticInsights TERMINAL
           </div>
           
           <div className="space-y-4">
@@ -247,13 +282,13 @@ export default function Home() {
         <div className="flex items-center gap-2">
           <Image 
             src="/logo_mark.png" 
-            alt="mem8" 
+            alt="AgenticInsights" 
             width={16} 
             height={16} 
             className="opacity-70"
           />
           <span className="text-xs text-muted-foreground font-mono">
-            mem8 Terminal v1.2.0
+            {getAppTitle()}
           </span>
         </div>
         <div className="flex items-center gap-3">
@@ -313,6 +348,36 @@ export default function Home() {
                 </div>
               )}
             </div>
+            
+            {/* Content Type Filter */}
+            <div className="flex gap-1 mt-3">
+              <Button
+                variant={contentTypeFilter === 'all' ? 'terminal' : 'outline'}
+                size="sm"
+                onClick={() => setContentTypeFilter('all')}
+                className="flex-1 text-xs font-mono"
+              >
+                All
+              </Button>
+              <Button
+                variant={contentTypeFilter === 'research' ? 'terminal' : 'outline'}
+                size="sm"
+                onClick={() => setContentTypeFilter('research')}
+                className="flex-1 text-xs font-mono"
+              >
+                <FileText className="w-3 h-3 mr-1" />
+                Research
+              </Button>
+              <Button
+                variant={contentTypeFilter === 'plan' ? 'terminal' : 'outline'}
+                size="sm"
+                onClick={() => setContentTypeFilter('plan')}
+                className="flex-1 text-xs font-mono"
+              >
+                <Code className="w-3 h-3 mr-1" />
+                Plans
+              </Button>
+            </div>
           </div>
 
           {/* System Metrics - Always Visible */}
@@ -320,7 +385,7 @@ export default function Home() {
             <div className="grid grid-cols-3 gap-2 text-center">
               <div className="flex flex-col">
                 <span className="text-lg font-bold terminal-glow text-primary">
-                  {filesystemThoughts?.total ?? systemStats?.totalThoughts ?? '0'}
+                  {fsThoughts?.total ?? systemStats?.totalThoughts ?? '0'}
                 </span>
                 <span className="text-xs text-muted-foreground">Thoughts</span>
               </div>
@@ -368,7 +433,7 @@ export default function Home() {
                       </Badge>
                     </div>
                     <div className="text-xs text-muted-foreground">
-                      {team.memberCount} members • {team.thoughtCount} thoughts
+                      {String(team.memberCount)} members • {String(team.thoughtCount)} thoughts
                     </div>
                   </div>
                 ))
@@ -429,7 +494,7 @@ export default function Home() {
           <div className="border-b border-border bg-muted/50">
             <div className="p-4 pb-2">
               <div className="terminal-text text-sm">
-                <span className="text-primary">{user?.username || 'user'}@mem8</span>
+                <span className="text-primary">{user?.username || 'user'}@agenticinsights</span>
                 <span className="text-muted-foreground">:</span>
                 <span className="text-accent">~/memories{searchQuery ? '/search' : ''}</span>
                 <span className="text-primary">$</span>
@@ -445,12 +510,12 @@ export default function Home() {
               <div className="flex items-center gap-3">
                 <span className="flex items-center gap-1">
                   <Database className="w-3 h-3" />
-                  {filesystemThoughts?.source === 'local-filesystem' ? 'Local' : 'Database'}
+                  {fsThoughts?.source === 'local-filesystem' ? 'Local' : 'Database'}
                 </span>
-                {filesystemThoughts?.repositories_found && filesystemThoughts.repositories_found.length > 0 && (
+                {fsThoughts?.repositories_found && fsThoughts.repositories_found.length > 0 && (
                   <>
                     <span>•</span>
-                    <span>Repos: {filesystemThoughts.repositories_found.join(', ')}</span>
+                    <span>Repos: {fsThoughts.repositories_found.join(', ')}</span>
                   </>
                 )}
                 {searchQuery && (
@@ -462,7 +527,7 @@ export default function Home() {
               </div>
               <div className="flex items-center gap-2">
                 <Badge variant="outline" className="text-xs">
-                  Showing {recentThoughts?.length ?? 0} of {filesystemThoughts?.total ?? systemStats?.totalThoughts ?? 0}
+                  Showing {recentThoughts?.length ?? 0} of {fsThoughts?.total ?? systemStats?.totalThoughts ?? 0}
                 </Badge>
               </div>
             </div>
@@ -474,18 +539,38 @@ export default function Home() {
               <h2 className="text-xl font-semibold mb-4 terminal-glow flex items-center gap-2">
                 <Brain className="w-5 h-5" />
                 {searchQuery ? 'Search Results' : 
-                 filesystemThoughts?.source === 'local-filesystem' ? 'Local Thoughts' : 
+                 fsThoughts?.source === 'local-filesystem' ? 'Local Thoughts' : 
                  'Recent Thoughts'}
+                {contentTypeFilter !== 'all' && (
+                  <Badge variant={contentTypeFilter === 'research' ? 'active' : 'syncing'} className="text-xs">
+                    {contentTypeFilter === 'research' ? 'Research' : 'Plans'}
+                  </Badge>
+                )}
               </h2>
               
               <div className="space-y-4">
                 {(thoughtsLoading || filesystemLoading) ? (
                   <div className="text-center text-muted-foreground">Loading thoughts...</div>
                 ) : recentThoughts.length > 0 ? (
-                  recentThoughts.map((thought) => (
-                    <div key={thought.id} className="memory-cell p-4 rounded-lg hover:scale-[1.02] transition-all cursor-pointer">
+                  // eslint-disable-next-line @typescript-eslint/no-explicit-any
+                  recentThoughts.map((thought: any, index: number) => (
+                    <div 
+                      key={`${thought.id}-${index}`} 
+                      className="memory-cell p-4 rounded-lg hover:scale-[1.02] transition-all cursor-pointer"
+                      onClick={() => router.push(`/thought/${thought.id}/edit`)}
+                    >
                       <div className="flex items-start justify-between mb-2">
-                        <h3 className="font-medium text-base">{thought.title}</h3>
+                        <div className="flex items-center gap-2">
+                          <h3 className="font-medium text-base">{thought.title}</h3>
+                          {thought.contentType !== 'thought' && (
+                            <Badge 
+                              variant={thought.contentType === 'research' ? 'active' : 'syncing'} 
+                              className="text-xs"
+                            >
+                              {thought.contentType === 'research' ? 'Research' : 'Plan'}
+                            </Badge>
+                          )}
+                        </div>
                         <Badge variant="terminal" className="text-xs shrink-0">
                           {thought.team}
                         </Badge>
@@ -506,13 +591,22 @@ export default function Home() {
                       
                       {thought.tags && thought.tags.length > 0 && (
                         <div className="flex flex-wrap gap-1 mt-2">
-                          {thought.tags.map((tag, index) => (
+                          {/* eslint-disable-next-line @typescript-eslint/no-explicit-any */}
+                          {thought.tags.map((tag: any, index: number) => (
                             <Badge key={`${tag}-${index}`} variant="outline" className="text-xs">
-                              {tag}
+                              {String(tag)}
                             </Badge>
                           ))}
                         </div>
                       )}
+                      
+                      {/* Add metadata panel for research/plans */}
+                      {thought.contentType !== 'thought' && thought.metadata && (
+                        <MetadataPanel 
+                          metadata={thought.metadata} 
+                          type={thought.contentType} 
+                        />
+                      )}
                     </div>
                   ))
                 ) : (
